@@ -51,7 +51,10 @@ class RexcelWorkbook:
             skip_rows: int = 0,
             freeze_panes: Tuple[int, int] = None,
             data_validation_columns: dict = None,
-            comment_column: str = None
+            right_df: pd.DataFrame = None,
+            comment_column: str = None,
+            header_format: Format = None,
+            hide_right_columns: str = None
     ):
         hidden_rows = hidden_rows or []
         hidden_columns = hidden_columns or []
@@ -87,6 +90,8 @@ class RexcelWorkbook:
         if data_validation_columns is not None:
             for data_validation_column in data_validation_columns:
                 columns.append(data_validation_column)
+        if right_df is not None:
+            columns.extend(right_df.columns.tolist())
         if comment_column is not None:
             columns.append(comment_column)
         for j, header in enumerate(columns):
@@ -95,9 +100,10 @@ class RexcelWorkbook:
             wks.write(
                 f"{self.get_column_letter(j)}{row_number + 1}",
                 header,
-                FORMATS.get('bold')
+                header_format or FORMATS.get('bold')
             )
         rows = df.values.tolist()
+        right_rows = right_df.values.tolist() if right_df is not None else right_df
         row_number += 1
         col_number = 0
         write_funcs = {
@@ -105,7 +111,7 @@ class RexcelWorkbook:
             bool: wks.write_boolean,
             int: wks.write_number
         }
-        for row in rows:
+        for i, row in enumerate(rows):
             offset = 0
             for j, cell in enumerate(row):
                 if type(cell) not in write_funcs:
@@ -148,6 +154,24 @@ class RexcelWorkbook:
                             data_validation
                         )
                     offset += 1
+            if right_rows is not None:
+                for k, cell in enumerate(right_rows[i]):
+                    if type(cell) not in write_funcs:
+                        cell = str(cell)
+                    cell_info = [
+                        row_number,
+                        col_number + offset,
+                        cell
+                    ]
+                    write_func = write_funcs.get(type(cell))
+                    if cell and isinstance(cell, str) and cell[0] == '=':
+                        write_func = wks.write_formula
+                    if cell == "":
+                        write_func = wks.write_blank
+                    write_func(
+                        *cell_info
+                    )
+                    offset += 1
             if comment_column is not None:
                 wks.write_blank(
                     row_number,
@@ -171,4 +195,13 @@ class RexcelWorkbook:
         if freeze_panes:
             freeze_row, freeze_column = freeze_panes
             wks.freeze_panes(freeze_row, freeze_column)
+        if hide_right_columns is not None:
+            wks.set_column(
+                hide_right_columns,
+                None,
+                None,
+                {
+                    'hidden': True
+                }
+            )
         self.worksheets.append(wks)
